@@ -16,6 +16,7 @@ from threadpoolctl import threadpool_limits
 
 import autosklearn.pipeline.classification
 import autosklearn.pipeline.regression
+from autosklearn.pipeline.components.base import ThirdPartyComponents, _addons
 from autosklearn.constants import (
     CLASSIFICATION_TASKS,
     REGRESSION_TASKS,
@@ -46,7 +47,7 @@ class MyDummyClassifier(DummyClassifier):
     def __init__(
         self,
         config: Configuration,
-        random_state: np.random.RandomState,
+        random_state: Optional[Union[int, np.random.RandomState]],
         init_params: Optional[Dict[str, Any]] = None,
         dataset_properties: Dict[str, Any] = {},
         include: Optional[List[str]] = None,
@@ -102,7 +103,7 @@ class MyDummyRegressor(DummyRegressor):
     def __init__(
         self,
         config: Configuration,
-        random_state: np.random.RandomState,
+        random_state: Optional[Union[int, np.random.RandomState]],
         init_params: Optional[Dict[str, Any]] = None,
         dataset_properties: Dict[str, Any] = {},
         include: Optional[List[str]] = None,
@@ -181,6 +182,7 @@ class AbstractEvaluator(object):
         backend: Backend,
         queue: multiprocessing.Queue,
         metric: Scorer,
+        additional_components: Dict[str, ThirdPartyComponents],
         port: Optional[int],
         configuration: Optional[Union[int, Configuration]] = None,
         scoring_functions: Optional[List[Scorer]] = None,
@@ -241,8 +243,7 @@ class AbstractEvaluator(object):
             self.predict_function = self._predict_proba
 
         self._init_params = {
-            'data_preprocessing:feat_type':
-                self.datamanager.feat_type
+            'data_preprocessor:feat_type': self.datamanager.feat_type
         }
 
         if init_params is not None:
@@ -269,6 +270,15 @@ class AbstractEvaluator(object):
         self.budget = budget
         self.budget_type = budget_type
 
+        # Add 3rd-party components to the list of 3rd-party components in case this wasn't done
+        # before (this happens if we run in parallel and the components are only passed to the
+        # AbstractEvaluator via the TAE and are not there yet because the worker is in its own
+        # process).
+        for key in additional_components:
+            for component_name, component in additional_components[key].components.items():
+                if component_name not in _addons[key].components:
+                    _addons[key].add_component(component)
+
         # Please mypy to prevent not defined attr
         self.model = self._get_model()
 
