@@ -1,5 +1,6 @@
 import logging
 import multiprocessing
+import warnings
 from typing import Any, Dict, List, Optional, Tuple, Union, cast
 
 import copy
@@ -21,6 +22,7 @@ from autosklearn.evaluation.abstract_evaluator import (
     TYPE_ADDITIONAL_INFO,
     _fit_and_suppress_warnings,
 )
+from autosklearn.evaluation.splitter import CustomStratifiedShuffleSplit, CustomStratifiedKFold
 from autosklearn.data.abstract_data_manager import AbstractDataManager
 from autosklearn.constants import (
     CLASSIFICATION_TASKS,
@@ -33,7 +35,7 @@ from autosklearn.data.validation import (
      SUPPORTED_TARGET_TYPES,
  )
 from autosklearn.pipeline.base import PIPELINE_DATA_DTYPE
-from autosklearn.pipeline.components.base import IterativeComponent
+from autosklearn.pipeline.components.base import IterativeComponent, ThirdPartyComponents
 from autosklearn.metrics import Scorer
 from autosklearn.util.backend import Backend
 from autosklearn.util.logging_ import PicklableClientLogger
@@ -158,6 +160,7 @@ class TrainEvaluator(AbstractEvaluator):
         backend: Backend,
         queue: multiprocessing.Queue,
         metric: Scorer,
+        additional_components: Dict[str, ThirdPartyComponents],
         port: Optional[int],
         configuration: Optional[Union[int, Configuration]] = None,
         scoring_functions: Optional[List[Scorer]] = None,
@@ -182,6 +185,7 @@ class TrainEvaluator(AbstractEvaluator):
             port=port,
             configuration=configuration,
             metric=metric,
+            additional_components=additional_components,
             scoring_functions=scoring_functions,
             seed=seed,
             output_y_hat_optimization=output_y_hat_optimization,
@@ -1037,15 +1041,20 @@ class TrainEvaluator(AbstractEvaluator):
 
                 if shuffle:
                     try:
-                        cv = StratifiedShuffleSplit(n_splits=1,
-                                                    test_size=test_size,
-                                                    random_state=1)
+                        cv = StratifiedShuffleSplit(
+                            n_splits=1,
+                            test_size=test_size,
+                            random_state=1,
+                        )
                         test_cv = copy.deepcopy(cv)
                         next(test_cv.split(y, y))
                     except ValueError as e:
                         if 'The least populated class in y has only' in e.args[0]:
-                            cv = ShuffleSplit(n_splits=1, test_size=test_size,
-                                              random_state=1)
+                            cv = CustomStratifiedShuffleSplit(
+                                n_splits=1,
+                                test_size=test_size,
+                                random_state=1,
+                            )
                         else:
                             raise e
                 else:
@@ -1057,9 +1066,26 @@ class TrainEvaluator(AbstractEvaluator):
             elif self.resampling_strategy in ['cv', 'cv-iterative-fit', 'partial-cv',
                                               'partial-cv-iterative-fit']:
                 if shuffle:
-                    cv = StratifiedKFold(
-                        n_splits=self.resampling_strategy_args['folds'],
-                        shuffle=shuffle, random_state=1)
+                    try:
+                        with warnings.catch_warnings():
+                            warnings.simplefilter('error')
+                            cv = StratifiedKFold(
+                                n_splits=self.resampling_strategy_args['folds'],
+                                shuffle=shuffle,
+                                random_state=1,
+                            )
+                            test_cv = copy.deepcopy(cv)
+                            next(test_cv.split(y, y))
+                    except UserWarning as e:
+                        print(e)
+                        if 'The least populated class in y has only' in e.args[0]:
+                            cv = CustomStratifiedKFold(
+                                n_splits=self.resampling_strategy_args['folds'],
+                                shuffle=shuffle,
+                                random_state=1,
+                            )
+                        else:
+                            raise e
                 else:
                     cv = KFold(n_splits=self.resampling_strategy_args['folds'],
                                shuffle=shuffle)
@@ -1139,6 +1165,7 @@ def eval_holdout(
     exclude: Optional[List[str]],
     disable_file_output: bool,
     port: Optional[int],
+    additional_components: Dict[str, ThirdPartyComponents],
     init_params: Optional[Dict[str, Any]] = None,
     budget: Optional[float] = 100.0,
     budget_type: Optional[str] = None,
@@ -1159,6 +1186,7 @@ def eval_holdout(
         include=include,
         exclude=exclude,
         disable_file_output=disable_file_output,
+        additional_components=additional_components,
         init_params=init_params,
         budget=budget,
         budget_type=budget_type,
@@ -1182,6 +1210,7 @@ def eval_iterative_holdout(
     exclude: Optional[List[str]],
     disable_file_output: bool,
     port: Optional[int],
+    additional_components: Dict[str, ThirdPartyComponents],
     init_params: Optional[Dict[str, Any]] = None,
     budget: Optional[float] = 100.0,
     budget_type: Optional[str] = None,
@@ -1203,6 +1232,7 @@ def eval_iterative_holdout(
         instance=instance,
         disable_file_output=disable_file_output,
         iterative=True,
+        additional_components=additional_components,
         init_params=init_params,
         budget=budget,
         budget_type=budget_type
@@ -1225,6 +1255,7 @@ def eval_partial_cv(
     exclude: Optional[List[str]],
     disable_file_output: bool,
     port: Optional[int],
+    additional_components: Dict[str, ThirdPartyComponents],
     init_params: Optional[Dict[str, Any]] = None,
     budget: Optional[float] = None,
     budget_type: Optional[str] = None,
@@ -1250,6 +1281,7 @@ def eval_partial_cv(
         include=include,
         exclude=exclude,
         disable_file_output=disable_file_output,
+        additional_components=additional_components,
         init_params=init_params,
         budget=budget,
         budget_type=budget_type,
@@ -1274,6 +1306,7 @@ def eval_partial_cv_iterative(
     exclude: Optional[List[str]],
     disable_file_output: bool,
     port: Optional[int],
+    additional_components: Dict[str, ThirdPartyComponents],
     init_params: Optional[Dict[str, Any]] = None,
     budget: Optional[float] = None,
     budget_type: Optional[str] = None,
@@ -1297,6 +1330,7 @@ def eval_partial_cv_iterative(
         exclude=exclude,
         disable_file_output=disable_file_output,
         iterative=True,
+        additional_components=additional_components,
         init_params=init_params,
     )
 
@@ -1318,6 +1352,7 @@ def eval_cv(
     exclude: Optional[List[str]],
     disable_file_output: bool,
     port: Optional[int],
+    additional_components: Dict[str, ThirdPartyComponents],
     init_params: Optional[Dict[str, Any]] = None,
     budget: Optional[float] = None,
     budget_type: Optional[str] = None,
@@ -1338,6 +1373,7 @@ def eval_cv(
         include=include,
         exclude=exclude,
         disable_file_output=disable_file_output,
+        additional_components=additional_components,
         init_params=init_params,
         budget=budget,
         budget_type=budget_type,
@@ -1362,6 +1398,7 @@ def eval_iterative_cv(
     exclude: Optional[List[str]],
     disable_file_output: bool,
     port: Optional[int],
+    additional_components: Dict[str, ThirdPartyComponents],
     init_params: Optional[Dict[str, Any]] = None,
     budget: Optional[float] = None,
     budget_type: Optional[str] = None,
@@ -1382,6 +1419,7 @@ def eval_iterative_cv(
         exclude=exclude,
         disable_file_output=disable_file_output,
         port=port,
+        additional_components=additional_components,
         init_params=init_params,
         budget=budget,
         budget_type=budget_type,
