@@ -9,8 +9,10 @@ from sklearn.utils.multiclass import type_of_target
 
 from smac.utils.constants import MAXINT
 
-from autosklearn.constants import REGRESSION_TASKS, TASK_TYPES
-
+from autosklearn.constants import (
+    BINARY_CLASSIFICATION, MULTICLASS_CLASSIFICATION, MULTILABEL_CLASSIFICATION,
+    MULTIOUTPUT_REGRESSION, REGRESSION, REGRESSION_TASKS, TASK_TYPES,
+)
 
 from .util import sanitize_array
 
@@ -541,3 +543,13 @@ def _compute_scorer(
     else:
         score = metric(solution, prediction)
     return score
+
+
+# Must be at bottom so all metrics are defined
+default_metric_for_task: Dict[int, Scorer] = {
+    BINARY_CLASSIFICATION: CLASSIFICATION_METRICS['accuracy'],
+    MULTICLASS_CLASSIFICATION: CLASSIFICATION_METRICS['accuracy'],
+    MULTILABEL_CLASSIFICATION: CLASSIFICATION_METRICS['f1_macro'],
+    REGRESSION: REGRESSION_METRICS['r2'],
+    MULTIOUTPUT_REGRESSION: REGRESSION_METRICS['r2'],
+}
