@@ -1,10 +1,11 @@
 __author__ = 'feurerm'
 
 from collections import OrderedDict
+from typing import Type
 import os
 
 from ..base import AutoSklearnClassificationAlgorithm, find_components, \
-    ThirdPartyComponents, AutoSklearnChoice
+    ThirdPartyComponents, AutoSklearnChoice, _addons
 from ConfigSpace.configuration_space import ConfigurationSpace
 from ConfigSpace.hyperparameters import CategoricalHyperparameter
 
@@ -12,11 +13,12 @@ classifier_directory = os.path.split(__file__)[0]
 _classifiers = find_components(__package__,
                                classifier_directory,
                                AutoSklearnClassificationAlgorithm)
-_addons = ThirdPartyComponents(AutoSklearnClassificationAlgorithm)
+additional_components = ThirdPartyComponents(AutoSklearnClassificationAlgorithm)
+_addons['classification'] = additional_components
 
 
-def add_classifier(classifier):
-    _addons.add_component(classifier)
+def add_classifier(classifier: Type[AutoSklearnClassificationAlgorithm]) -> None:
+    additional_components.add_component(classifier)
 
 
 class ClassifierChoice(AutoSklearnChoice):
@@ -25,7 +27,7 @@ class ClassifierChoice(AutoSklearnChoice):
     def get_components(cls):
         components = OrderedDict()
         components.update(_classifiers)
-        components.update(_addons.components)
+        components.update(additional_components.components)
         return components
 
     def get_available_components(cls, dataset_properties=None,
@@ -78,8 +80,8 @@ class ClassifierChoice(AutoSklearnChoice):
             dataset_properties = {}
 
         if include is not None and exclude is not None:
-            raise ValueError("The arguments include_estimators and "
-                             "exclude_estimators cannot be used together.")
+            raise ValueError("The arguments include and "
+                             "exclude cannot be used together.")
 
         cs = ConfigurationSpace()
 
