@@ -17,7 +17,10 @@ class CategoryShift(AutoSklearnPreprocessingAlgorithm):
     is not used, so to provide compatibility with sparse matrices.
     """
 
-    def __init__(self, random_state: Optional[np.random.RandomState] = None):
+    def __init__(
+        self,
+        random_state: Optional[Union[int, np.random.RandomState]] = None
+    ) -> None:
         self.random_state = random_state
 
     def fit(self, X: PIPELINE_DATA_DTYPE, y: Optional[PIPELINE_DATA_DTYPE] = None
